# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageMediaDocument(Object):
    """
    Attributes:
        ID (:obj:`int`): ``0x7c4414d3``

    Args:
        document: :class:`pyrogram.api.types.Document` (optional)
        caption: :obj:`string` (optional)
        ttl_seconds: :obj:`int` (optional)
    """
    ID = 0x7c4414d3

    def __init__(self, document=None, caption=None, ttl_seconds=None, **kwargs):
        self.document = document  # flags.0?Document
        self.caption = caption  # flags.1?string
        self.ttl_seconds = ttl_seconds  # flags.2?int

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageMediaDocument":
        flags = Int.read(b)
        
        document = Object.read(b) if flags & (1 << 0) else None
        
        caption = String.read(b) if flags & (1 << 1) else None
        ttl_seconds = Int.read(b) if flags & (1 << 2) else None
        return MessageMediaDocument(document, caption, ttl_seconds)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.document is not None else 0
        flags |= (1 << 1) if self.caption is not None else 0
        flags |= (1 << 2) if self.ttl_seconds is not None else 0
        b.write(Int(flags))
        
        if self.document is not None:
            b.write(self.document.write())
        
        if self.caption is not None:
            b.write(String(self.caption))
        
        if self.ttl_seconds is not None:
            b.write(Int(self.ttl_seconds))
        
        return b.getvalue()
